All platforms.

environ.core


envclj/s

A map of environment variables.

A map of environment variables.
sourceraw docstring

read-envclj/s

(read-env)

Read and return the environment map from all sources at call time.

env is read once when this namespace loads, which is fixed at build time under GraalVM native-image (and at uberjar build for compiled code). Call read-env instead to re-read the live environment at runtime.

Read and return the environment map from all sources at call time.

`env` is read once when this namespace loads, which is fixed at *build*
time under GraalVM native-image (and at uberjar build for compiled code).
Call `read-env` instead to re-read the live environment at runtime.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries