(read-env)Read and return the environment map from all sources at call time.
env is read once when this namespace loads, which is fixed at build
time under GraalVM native-image (and at uberjar build for compiled code).
Call read-env instead to re-read the live environment at runtime.
Read and return the environment map from all sources at call time. `env` is read once when this namespace loads, which is fixed at *build* time under GraalVM native-image (and at uberjar build for compiled code). Call `read-env` instead to re-read the live environment at runtime.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |